@@ -41,7 +41,7 @@ class DualDataset(Dataset):
 
     @classmethod
     def from_sources(cls, source0: pd.DataFrame, source1: pd.DataFrame = None, matching_info_source0=None,
-                     matching_info_source1=None, matching_fn=None, separator: pd.Series = None):
+                     matching_info_source1=None, matching_fn=None, separator: pd.Series = None,**kwargs):
 
         dual_entities_list = []
         source0, source1, matching_info_source0, matching_info_source1, matching_fn = cls._adjust_inputs(source0,
@@ -62,7 +62,7 @@ class DualDataset(Dataset):
                 entity_dict['FIELD1'] = field1
                 entity_dict['ID1'] = source1.index[index_field1]
             dual_entities_list.append(DualEntity(entity_dict))
-        return cls(dual_entities_list)
+        return cls(dual_entities_list, **kwargs)
 
     @staticmethod
     def _adjust_inputs(source0: pd.DataFrame, source1: pd.DataFrame = None, matching_info_source0=None,
